package com.qmth.ops.biz.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.boot.core.ai.model.llm.LlmAppType;
import com.qmth.ops.biz.dao.LlmOrgConfigDao;
import com.qmth.ops.biz.domain.LlmModel;
import com.qmth.ops.biz.domain.LlmOrgConfig;
import com.qmth.ops.biz.domain.Org;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

@Service
public class LlmOrgConfigService extends ServiceImpl<LlmOrgConfigDao, LlmOrgConfig> {

    @Resource
    private LlmOrgConfigDao llmOrgConfigDao;

    public LlmOrgConfig findByOrgAndAppType(Org org, LlmAppType appType) {
        return llmOrgConfigDao.selectOne(new LambdaQueryWrapper<LlmOrgConfig>().eq(LlmOrgConfig::getOrgId, org.getId())
                .eq(LlmOrgConfig::getAppType, appType));
    }

    @Transactional
    public void updateModel(LlmOrgConfig llmOrgConfig, LlmModel model) {
        llmOrgConfigDao.update(llmOrgConfig,
                new LambdaUpdateWrapper<LlmOrgConfig>().set(LlmOrgConfig::getModelId, model.getId())
                        .eq(LlmOrgConfig::getOrgId, llmOrgConfig.getOrgId())
                        .eq(LlmOrgConfig::getAppType, llmOrgConfig.getAppType()));
    }

    @Transactional
    public void permit(LlmOrgConfig llmOrgConfig, int count) {
        llmOrgConfigDao.permit(llmOrgConfig.getOrgId(), llmOrgConfig.getAppType(), count);
    }

    @Transactional
    public void consume(LlmOrgConfig llmOrgConfig) {
        llmOrgConfigDao.consume(llmOrgConfig.getOrgId(), llmOrgConfig.getAppType());
    }

}

